You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@isis.apache.org by ah...@apache.org on 2018/08/30 12:38:57 UTC

[isis] 01/04: ISIS-1895: improves java-doc

This is an automated email from the ASF dual-hosted git repository.

ahuber pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/isis.git

commit ae14bae36c3ade7fd31e0127aaa6817d769f4bda
Author: Andi Huber <ah...@apache.org>
AuthorDate: Thu Aug 30 07:00:24 2018 +0200

    ISIS-1895: improves java-doc
    
    Task-Url: https://issues.apache.org/jira/browse/ISIS-1895
---
 .../org/apache/isis/core/webapp/IsisWebAppContextListener.java    | 2 +-
 .../main/java/org/apache/isis/core/webapp/modules/WebModule.java  | 8 ++++++--
 2 files changed, 7 insertions(+), 3 deletions(-)

diff --git a/core/runtime/src/main/java/org/apache/isis/core/webapp/IsisWebAppContextListener.java b/core/runtime/src/main/java/org/apache/isis/core/webapp/IsisWebAppContextListener.java
index 6579f22..99a596a 100644
--- a/core/runtime/src/main/java/org/apache/isis/core/webapp/IsisWebAppContextListener.java
+++ b/core/runtime/src/main/java/org/apache/isis/core/webapp/IsisWebAppContextListener.java
@@ -36,7 +36,7 @@ import org.apache.isis.core.webapp.modules.WebModule;
 
 /**
  * 
- * Introduced to render web.xml listener configurations obsolete.
+ * Introduced to render web.xml Filter/Listener/Servlet configurations obsolete.
  * <p> 
  * Acts as the single application entry-point for setting up the 
  * ServletContext programmatically.
diff --git a/core/runtime/src/main/java/org/apache/isis/core/webapp/modules/WebModule.java b/core/runtime/src/main/java/org/apache/isis/core/webapp/modules/WebModule.java
index a7cf761..d24d0f4 100644
--- a/core/runtime/src/main/java/org/apache/isis/core/webapp/modules/WebModule.java
+++ b/core/runtime/src/main/java/org/apache/isis/core/webapp/modules/WebModule.java
@@ -20,14 +20,17 @@ package org.apache.isis.core.webapp.modules;
 
 import java.util.stream.Stream;
 
+import javax.servlet.Filter;
+import javax.servlet.Servlet;
 import javax.servlet.ServletContext;
 import javax.servlet.ServletContextListener;
 import javax.servlet.ServletException;
+import javax.servlet.annotation.WebListener;
 
 import org.apache.isis.core.webapp.IsisWebAppContextListener;
 
 /**
  * Introduced to render web.xml listener configurations obsolete.
  * <p>
  * WebModule instances are used by the {@link IsisWebAppContextListener} to setup 
  * the ServletContext programmatically.
@@ -45,7 +48,8 @@ public interface WebModule {
     public String getName();
     
     /**
      * Sets the WebListener up and registers it with the given ServletContext {@code ctx}.
      * @param ctx ServletContext
      */
     public ServletContextListener init(ServletContext ctx) throws ServletException;
@@ -20,14 +20,17 @@ package org.apache.isis.core.webapp.modules;
 
 /**
- * Introduced to render web.xml listener configurations obsolete.
+ * Introduced to render web.xml Filter/Listener/Servlet configurations obsolete.
  * <p>
  * WebModule instances are used by the {@link IsisWebAppContextListener} to setup 
@@ -45,7 +48,8 @@ public interface WebModule {
     
     /**
-     * Sets the WebListener up and registers it with the given ServletContext {@code ctx}.
+     * Sets this WebModule's {@link Filter}s, {@link Servlet}s or {@link WebListener}s 
+     * up and registers them with the given {@link ServletContext} {@code ctx}.
      * @param ctx ServletContext
      */